{-|
Module      : Gargantext.Prelude.NLP
Description :
Copyright   : (c) CNRS, 2017-Present
License     : AGPL + CECILL v3
Maintainer  : team@gargantext.org
Stability   : experimental
Portability : POSIX

-}

module Gargantext.Prelude.NLP
  (NLPConfig(..), readConfig)
  where

import Data.Text (Text, unpack)
import qualified Data.Text as T
import Data.Maybe
import Gargantext.Prelude
import Gargantext.Prelude.Config (readIniFile', val)
import Gargantext.Prelude.NLP.Types (NLPConfig(..))
import Network.URI (parseURI)
import System.IO (FilePath)


type URL = Text

readConfig :: FilePath -> IO NLPConfig
readConfig fp = do
  ini <- readIniFile' fp
  let val' = val ini "nlp"

  let m_nlp_en = parseURI $ cs $ val' "EN"
  let m_nlp_fr = parseURI $ cs $ val' "FR"
  let m_nlp_all = parseURI $ cs $ val' "All"

  let mRet = NLPConfig <$> m_nlp_en <*> m_nlp_fr <*> m_nlp_all

  case mRet of
    Nothing -> panic $ T.concat [ "Cannot read config file: _nlp_en = "
                                , T.pack $ show m_nlp_en
                                , ", _nlp_fr = "
                                , T.pack $ show m_nlp_fr
                                , ", _nlp_all = "
                                , T.pack $ show m_nlp_all ]
    Just ret -> pure ret
